<?php

class rex_fe_plugin_factory {

    static function getPluginTitle($addon, $plugin) {
        return OOPlugin::getProperty($addon, $plugin, 'page');
    }

    static function getPluginDescription($addon, $plugin) {
        return OOPlugin::getProperty($addon, $plugin, 'description');
    }

    static function getAvailablePlugins($addon) {
        return OOPlugin::getAvailablePlugins($addon);
    }

    static function hasPluginSubpage($addon, $plugin) {
        global $REX;

        $hasSubpage = false;

        for ($i = 0; $i < count($REX['ADDON'][$addon]['SUBPAGES']); $i++) {
            if ($REX['ADDON'][$addon]['SUBPAGES'][$i][0] == 'plugin.' . $plugin) {
                $hasSubpage = true;
                break;
            }
        }

        return $hasSubpage;
    }

    static function registerPlugin($addon, $plugin, $title, $description, $version, $author, $supportPage, $hasBackendPage, $hasSubPages = array(), $permission = '') {
        global $REX;

        $REX['ADDON']['page'][$plugin] = $title;
        $REX['ADDON']['version'][$plugin] = $version;
        $REX['ADDON']['author'][$plugin] = $author;
        $REX['ADDON']['supportpage'][$plugin] = $supportPage;
        $REX['ADDON']['description'][$plugin] = $description;

        if ($permission != '') {
            $REX['ADDON']['perm'][$plugin] = $permission;
            $REX['PERM'][] = $permission;
        }

        if ($hasBackendPage) {
            $REX['ADDON'][$addon]['SUBPAGES'][] = array('plugin.' . $plugin, $title);
        }

        if ($hasSubPages != false) {
            #$REX['ADDON'][$addon]['SUBPAGES'][$plugin]['subsubpages'] = $hasSubPages;
            #print_r($REX['ADDON']);
            $REX['ADDON'][$addon]['SETTINGS'][$plugin]['subsubpages'] = $hasSubPages;
        }
    }

    static function printPluginList($addon, $headline, $noPluginsAvailafeMsg) {
        global $REX;
        global $I18N;
        $plugins = self::getAvailablePlugins($addon);

        if (count($plugins) < 1) {
            echo rex_info($noPluginsAvailafeMsg);
        } else {
            echo '<table id="fe-utilities-overview" class="rex-table">';
            echo '<tr><th>' . $headline . '</th></tr>';

            foreach ($plugins as $plugin) {
                // description
                $htmlDescription = '';
                $description = self::getPluginDescription($addon, $plugin);

                if ($description != '') {
                    $htmlDescription = '<p>' . $description . '</p>';
                }

                // link
                $htmlLink = 'index.php?page=' . $addon . '&amp;subpage=plugin.' . $plugin;

                // title and css class
                if (self::hasPluginSubpage($addon, $plugin)) {
                    $htmlTitle = '<a href="' . $htmlLink . '">' . self::getPluginTitle($addon, $plugin) . '</a>' . $htmlDescription;
                    $htmlIcon = '<a href="' . $htmlLink . '"><div class="plugin-icon"></div></a>';
                } else {
                    $htmlTitle = '<span>' . self::getPluginTitle($addon, $plugin) . '</span>' . $htmlDescription;
                    $htmlIcon = '<div class="plugin-icon grey"></div>';
                }

                // table row
                echo '<tr><td>' . $htmlIcon . '<div class="right">';
                echo $htmlTitle;
                echo '</div></td></tr>';
            }
            /*
             * $otherPlugins    = rex_read_addons_folder($REX['INCLUDE_PATH'] . '/addons/fe_utilities/plugins');
             * 
             * 
             */
            $allPlugins = rex_read_plugins_folder('fe_utilities');

            echo '</table>';

            if ($REX['USER']->isAdmin()) {

                echo '
                    <table class="rex-table" summary="' . $I18N->msg("addon_summary") . '">
                    <caption>' . $I18N->msg("addon_caption") . '</caption>
                    <colgroup>
                      <col width="40" />
                      <col width="*"/>
                      <col width="130" />
                      <col width="130" />
                      <!--<col width="130" />-->
                      <!--<col width="153" />-->
                    </colgroup>
                    <thead>
                      <tr>
                        <th class="rex-col-e" colspan="6">Alle Plugins</th>
                      </tr>
                      <tr>
                        <th class="rex-icon rex-col-a">&nbsp;</th>
                        <th class="rex-col-b">' . $I18N->msg("addon_hname") . '</th>
                        <th class="rex-col-c">' . $I18N->msg("addon_hinstall") . '</th>
                        <th class="rex-col-d">' . $I18N->msg("addon_hactive") . '</th>
                        <!--<th class="rex-col-e" colspan="2">' . $I18N->msg("addon_hdelete") . '</th>-->
                      </tr>
                    </thead>
                    <tbody>';

                foreach ($allPlugins as $plugin) {
                    $pluginurl = 'index.php?page=addon&amp;addonname=' . $addon . '&amp;pluginname=' . $plugin . '&amp;';

                    $delete = '<a href="' . $pluginurl . 'delete=1" onclick="return confirm(\'' . htmlspecialchars($I18N->msg('plugin_delete_question', $plugin)) . '\');">' . $I18N->msg("addon_delete") . '</a>';

                    if (OOPlugin::isInstalled($addon, $plugin)) {
                        $install = $I18N->msg("addon_yes") . ' - <a href="' . $pluginurl . 'install=1">' . $I18N->msg("addon_reinstall") . '</a>';
                        $uninstall = '<a href="' . $pluginurl . 'uninstall=1" onclick="return confirm(\'' . htmlspecialchars($I18N->msg("plugin_uninstall_question", $plugin)) . '\');">' . $I18N->msg("addon_uninstall") . '</a>';
                    } else {
                        $install = $I18N->msg("addon_no") . ' - <a href="' . $pluginurl . 'install=1">' . $I18N->msg("addon_install") . '</a>';
                        $uninstall = $I18N->msg("addon_notinstalled");
                    }

                    if (OOPlugin::isActivated($addon, $plugin)) {
                        $status = $I18N->msg("addon_yes") . ' - <a href="' . $pluginurl . 'activate=0">' . $I18N->msg("addon_deactivate") . '</a>';
                    } elseif (OOPlugin::isInstalled($addon, $plugin)) {
                        $status = $I18N->msg("addon_no") . ' - <a href="' . $pluginurl . 'activate=1">' . $I18N->msg("addon_activate") . '</a>';
                    } else {
                        $status = $I18N->msg("addon_notinstalled");
                    }

                    echo '
                        <tr class="rex-plugin">
                          <td class="rex-icon rex-col-a"><span class="rex-i-element rex-i-plugin"><span class="rex-i-element-text">' . htmlspecialchars($plugin) . '</span></span></td>
                          <td class="rex-col-b">' . htmlspecialchars($plugin) . ' [<a href="index.php?page=addon&amp;subpage=help&amp;addonname=' . $addon . '&amp;pluginname=' . $plugin . '">?</a>]</td>
                          <td class="rex-col-c">' . $install . '</td>
                          <td class="rex-col-d">' . $status . '</td>
                          <!--<td class="rex-col-e">' . $uninstall . '</td>-->
                          <!--<td class="rex-col-f">' . $delete . '</td>-->
                        </tr>' . "\n   ";
                }//endforeach
                echo '</table>';
            }//endif admin
        }
    }

    static function getMediaAddonDir() {
        global $REX;

        // check for media addon dir var introduced in REX 4.5
        if (isset($REX['MEDIA_ADDON_DIR'])) {
            return $REX['MEDIA_ADDON_DIR'];
        } else {
            return 'files/addons';
        }
    }

    /*
     * subsubpages in subnavi einbinden
     */

    static function printPluginSubPages($addon, $plugin, $subsubpage) {
        global $REX;


        #$pages = $REX['ADDON'][$addon]['SUBPAGES'][$plugin]['subsubpages'];
        #print_r($REX['ADDON'][$addon]['SUBPAGES']);

        $pages = $REX['ADDON'][$addon]['SETTINGS'][$plugin]['subsubpages'];

        if (isset($addon) && isset($plugin) && $pages != false) {

            $out = '<div id="rex-navi-page">';
            $out .= '<ul style="margin:0 8px;padding:0;height:auto;">';

            foreach ($pages as $key => $value) {

                if ($key === $subsubpage) {
                    $active = 'rex-active';
                } else {
                    $active = '';
                }

                $out .= '<li>';

                $link = 'index.php?page=' . $addon . '&amp;subpage=plugin.' . $plugin . '&amp;subsubpage=' . $key;

                $out .= '<a class="' . $active . '" href="' . $link . '">' . $value . '</a>';

                $out .= '</li>';
            }

            $out .= '</ul>';
            $out .= '</div>';

            return $out;
        } else {
            return false;
        }
    }

}
