<?php
/**
 * Layout top und bottom wird bereits eingebunden
 */
$basedir = dirname(__FILE__);
$page = rex_request('page', 'string');
$subpage = rex_request('subpage', 'string');
$func = rex_request('func', 'string');
?>

<div class="rex-addon-output">

    <div class="rex-content-block" style="float:right;font-size: 120%;padding:10px;line-height:1.5em">
        <ul>
            <li><a href="#info">Informationen</a></li>
            <li><a href="#frontend">Frontend Beispiele</a></li>
            <li><a href="#backend">Backend Beispiele</a></li>
            <li><a href="#class">Die Klasse</a></li>
        </ul>
    </div>

    <h3 class="rex-hl2"><a name="info">Informationen</a></h3>
    <div class="rex-area-content">
        <p class="fe_utilities_slim">
            Bei easyTags wurde vor allem Wert auf flexibilität gelegt. Es soll mit
            wenig Code flexibel einsetzbar sein. Und es soll auf das Wesentliche
            beschränkt sein. Daher ist auch keine
            zusätzliche Datenbanktabelle notwendig. Die Tag's werden entweder aus den
            SEO42 Keywords geholt oder es kann ein beliebiges Meta-Info Feld gewählt werden.
            Die Worte müssen mit einem Komma getrennt sein.
        </p>
        <p class="fe_utilities_slim">
            Die Tag's werden im Backend generiert, das heisst es werden die Keywords aller
            Online-Artikel ausgelesen und in Arrays gepackt. Die Arrays werden anschliessend 
            in Dateien gespeichert. 
        </p>

        <h4>Einstellungen</h4>
        <p class="fe_utilities_slim">
            Unter Einstellungen können einige Werte festgelegt werden. Es kann aber praktisch
            alles in einer Instanz wieder überschrieben werden.
        </p>
    </div>
</div>

<div class="rex-addon-output">
    <h3 class="rex-hl2">
        <a name="frontend">Frontend Beispiele</a>
        <a style="display: inline-block;float: right" href="javascript:self.scrollTo(0,0);" title="nach oben">nach oben</a>
    </h3>
    <div class="rex-area-content">
        <p class="fe_utilities_slim">Hier nun einige Beispiele wie Easy Tags im Frontend genutzt werden kann.</p>

        <h4>Ausgabe der Arrays</h4>
        <p class="fe_utilities_slim">
            Als erstes eine Instanz aufrufen. Danach hat man mehrere Möglichkeiten.
            Hier als erstes mal die Arrays.
        </p>
        <div class="rex-code">
<?php
highlight_string('<?php
$tags = new easyTags1135();

/*
 * Folgendes gibt ein Array zurück welches alle Tags der wichtigkeit nach 
 * sortiert enthält.
 * Beispiel: $TAG_MAP[\'MeinTag\'] = 22
 * Der Key entspricht dem Tag-Namen und der Wert der Anzahl Vorkommen
 */
$TAG_MAP = $tags->getTagMap();

/*
 * Folgendes gibt ein Array zurück welches Listen aller Artikel enthält.
 * Beispiel: $TAG_LIST[\'MeinTag\'][0] = 22
 * Der Key entspricht dem Tag-Namen und der Wert ist ein Array mit allen Artikel-ID\'s
 */
$TAG_LIST = $tags->getTagList();

/*
 * Folgendes gibt ein Array zurück welches die Tags aller Artikel enthält.
 * Beispiel: $TAG_LIST[\'22\'][0] = MeinTag
 * Der Key entspricht der Artikel-ID und der Wert ist ein Array mit allen Tags
 */
$TAG_ARTS = $tags->getTagArts();
?>');
?>
        </div>
        <p class="fe_utilities_slim">
            Die Arrays können nun in Templates oder Modulen weiter verarbeitet werden.
        </p>


        <h4>Ausgabe der Fertigen Elemente</h4>
        <p class="fe_utilities_slim">
            Hier wird die TagCloud und eine Artikel-Listen aufgerufen.
        </p>
        <div class="rex-code">
<?php
highlight_string('<?php
$tags = new easyTags1135();

/*
 * Folgendes gibt eine fertige TagCloud zurück.
 */
$tagcloud = $tags->getTagCloud();

/*
 * Folgendes gibt ein fertig formatierte Liste aller Artikel zu einem Tag aus.
 */
$artlist = $tags->getTagListSite(\'MeinTag\');
?>');
?>
        </div>
        <p class="fe_utilities_slim">
            Kann so in Modulen und Templates eingesetzt werden.
        </p>

    </div>
</div>
<div class="rex-addon-output">
    <h3 class="rex-hl2">
        <a name="backend">Backend Beispiele</a>
        <a style="display: inline-block;float: right" href="javascript:self.scrollTo(0,0);" title="nach oben">nach oben</a>
    </h3>
    <div class="rex-area-content">
        <p class="fe_utilities_slim">
            Hier einige Beispiele wie easyTags im Backend genutzt werden kann. 
            Unter "Einstellungen -> Eigene Backendseite" kann ein zusätzlicher
            Menupunkt angelegt werden für eigenen Backend-Code. Es muss dann
            im Ordner "pages" eine Datei namens "mypage.inc.php" angelegt werden.
        </p>

        <h4>Cache generieren</h4>
        <p class="fe_utilities_slim">
            Als erstes eine Instanz aufrufen. Dann wird  der Speicher neu
            eingelesen also die Arrays erstellt und dann werden noch die Cloud und die Listen generiert.
            Das ist genau das was die Buttons auf der Übersichtsseite machen.
        </p>
        <p class="fe_utilities_slim"> 
            Es wäre auch denkbar diesen Vorgang in gewissen Extension Points
            auszuführen um nach Änderungen in REDAXO, easyTags automatisch zu 
            aktualisieren. Dies wird wohl in einer künftigen Version eingebaut.
        </p>
        <div class="rex-code">
<?php
highlight_string('<?php
/*
 * Als erstes wird eine Instanz aufgerufen
 */
$tags = new easyTags1135();

/*
 * Nun werden alle Artikel eingelesen und die Daten werden in Arrays
 * gespeichert, die später im Frontend genutzt werden können.
 */
$tags->create_cache(); //würde true zurück geben oder eine Fehlermeldung

/*
 * Hier wird eine fertige TagCloud erstellt und anschliessend gespeichert.
 * Die Daten werden aus den zuvor generierten Arrays geholt.
 */
$tags->make_tag_cloud(); //würde true zurück geben oder eine Fehlermeldung

/*
 * Hier werden fertige Listen erstellt die alle Artikel zu einem Tag
 * enthalten. Das wäre dann die Zielseite der Tags
 */
$tags->make_tag_list(); //würde true zurück geben oder eine Fehlermeldung
?>');
?>
        </div>
        <p class="fe_utilities_slim">
            Es ist auch möglich gewisse Parameter vor der Generierung anzupassen.
            Am besten hilft ein <a href="#class">Blick in die Klasse</a>.
        </p>
        <div class="rex-code">
<?php
highlight_string('<?php
$tags = new easyTags1135();

/*
 * So kann zB. der default Query für die Datenbank Abfrage geändert 
 * werden. Etwa um die WHERE Bedingung anzupassen.
 * Weiter Möglichkeiten sieht man in der Klasse selbst
 */
$tags->sql_query = "SELECT id, ###Keyword-Spalte###  FROM ###REX_###article
                                     WHERE status = \'1\'
                                ";
$tags->create_cache();
?>');
?>
        </div>
        <p class="fe_utilities_slim">
            Man kann auch gleich die Zeit noch messen die benötigt wird.
        </p>
        <div class="rex-code">
<?php
highlight_string('<?php
$tags = new easyTags1135();

$tags->start_time(); //timer starten

$tags->create_cache();
$tags->make_tag_cloud();
$tags->make_tag_list();

/*
 * Gibt aus wie lange die Ausführung dauerte.
 */
echo $tags->stop_time() . \'Sekunden\';
?>');
?>
        </div>
    </div>
</div>




<div class="rex-addon-output">
    <h3 class="rex-hl2">
        <a name="class">Die Klasse</a>
        <a style="display: inline-block;float: right" href="javascript:self.scrollTo(0,0);" title="nach oben">nach oben</a>
    </h3>
    <div class="rex-area-content">
        <p class="fe_utilities_slim">
            Hier noch die Klasse zur Ansicht.
        </p>

        <div class="rex-code">
<?php
highlight_file($REX['INCLUDE_PATH'] . "/addons/fe_utilities/plugins/feu_easy_tags/classes/class.easyTags1135.inc.php");
?>
        </div>
        <h4><a style="display: inline-block;" href="javascript:self.scrollTo(0,0);" title="nach oben">nach oben</a></h4>
    </div>
</div>





